@@ -17,7 +17,6 @@ use {
         QueueableCommand,
     },
     lfs_core::Mount,
-    minimad::Alignment,
     std::{
         convert::TryInto,
         fs,
@@ -25,7 +24,10 @@ use {
         path::Path,
     },
     strict::NonEmptyVec,
-    termimad::ProgressBar,
+    termimad::{
+        minimad::Alignment,
+        *,
+    },
 };
 
 struct FilteredContent {
@@ -106,9 +108,15 @@ impl FilesystemState {
     ) -> bool {
         let old_scroll = self.scroll;
         self.scroll = cmd.apply(self.scroll, self.count(), self.page_height);
+        if self.selection_idx < self.scroll {
+            self.selection_idx = self.scroll;
+        } else if self.selection_idx >= self.scroll + self.page_height {
+            self.selection_idx = self.scroll + self.page_height - 1;
+        }
         self.scroll != old_scroll
     }
 
+    /// change the selection
     fn move_line(
         &mut self,
         internal_exec: &InternalExecution,
@@ -123,6 +131,11 @@ impl FilesystemState {
         } else {
             self.selection_idx = move_sel(self.selection_idx, self.mounts.len().get(), dir, cycle);
         }
+        if self.selection_idx < self.scroll {
+            self.scroll = self.selection_idx;
+        } else if self.selection_idx >= self.scroll + self.page_height {
+            self.scroll = self.selection_idx + 1 - self.page_height;
+        }
         CmdResult::Keep
     }
 
@@ -220,13 +233,13 @@ impl PanelState for FilesystemState {
     ) -> Result<(), ProgramError> {
         let area = &disc.state_area;
         let con = &disc.con;
-        self.page_height = area.height as usize;
+        self.page_height = area.height as usize - 2;
         let (mounts, selection_idx) = if let Some(filtered) = &self.filtered {
             (filtered.mounts.as_slice(), filtered.selection_idx)
         } else {
             (self.mounts.as_slice(), self.selection_idx)
         };
-        let scrollbar = area.scrollbar(self.scroll as i32, mounts.len() as i32);
+        let scrollbar = area.scrollbar(self.scroll, mounts.len());
         //- style preparation
         let styles = &disc.panel_skin.styles;
         let selection_bg = styles.selected_line.get_bg()
@@ -304,7 +317,7 @@ impl PanelState for FilesystemState {
         cw.queue_g_string(&styles.default, format!("{:width$}", "filesystem", width = wc_fs))?;
         cw.queue_char(border_style, '│')?;
         if e_dsk {
-            cw.queue_g_string(&styles.default, " dsk ".to_string())?;
+            cw.queue_g_string(&styles.default, "disk ".to_string())?;
             cw.queue_char(border_style, '│')?;
         }
         if e_type {
@@ -350,7 +363,7 @@ impl PanelState for FilesystemState {
                 let match_style = if selected { &selected_match_style } else { &match_style };
                 let border_style = if selected { &selected_border_style } else { &border_style };
                 if con.show_selection_mark {
-                    cw.queue_char(&txt_style, if selected { '▶' } else { ' ' })?;
+                    cw.queue_char(txt_style, if selected { '▶' } else { ' ' })?;
                 }
                 // fs
                 let s = &mount.info.fs;
@@ -395,13 +408,16 @@ impl PanelState for FilesystemState {
                 }
                 // size, used, free
                 if let Some(stats) = mount.stats.as_ref().filter(|s| s.size() > 0) {
+                    let share_color = super::share_color(stats.use_share());
                     // size
                     cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(mount.size())))?;
                     cw.queue_char(border_style, '│')?;
                     // used
                     if e_use {
                         cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(stats.used())))?;
-                        let share_color = super::share_color(stats.use_share());
+                        if e_use_share {
+                            cw.queue_g_string(txt_style, format!("{:>3.0}%", 100.0*stats.use_share()))?;
+                        }
                         if e_use_bar {
                             cw.queue_char(txt_style, ' ')?;
                             let pb = ProgressBar::new(stats.use_share() as f32, w_use_bar);
@@ -409,15 +425,12 @@ impl PanelState for FilesystemState {
                             bar_style.set_bg(share_color);
                             cw.queue_g_string(&bar_style, format!("{:<width$}", pb, width=w_use_bar))?;
                         }
-                        if e_use_share {
-                            let mut share_style = txt_style.clone();
-                            share_style.set_fg(share_color);
-                            cw.queue_g_string(&share_style, format!("{:>3.0}%", 100.0*stats.use_share()))?;
-                        }
                         cw.queue_char(border_style, '│')?;
                     }
                     // free
-                    cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(stats.available())))?;
+                    let mut share_style = txt_style.clone();
+                    share_style.set_fg(share_color);
+                    cw.queue_g_string(&share_style, format!("{:>4}", file_size::fit_4(stats.available())))?;
                     cw.queue_char(border_style, '│')?;
                 } else {
                     // size
@@ -544,11 +557,15 @@ impl PanelState for FilesystemState {
                 }
             }
             Internal::page_down => {
-                self.try_scroll(ScrollCommand::Pages(1));
+                if !self.try_scroll(ScrollCommand::Pages(1)) {
+                    self.selection_idx = self.count() - 1;
+                }
                 CmdResult::Keep
             }
             Internal::page_up => {
-                self.try_scroll(ScrollCommand::Pages(-1));
+                if !self.try_scroll(ScrollCommand::Pages(-1)) {
+                    self.selection_idx = 0;
+                }
                 CmdResult::Keep
             }
             open_leave => CmdResult::PopStateAndReapply,
